@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 189 2012-06-04 21:56:37Z yablacky $
+# $Id: smscon_service.py 193 2012-06-05 23:07:49Z yablacky $
 ##############################################################
 
 # standard modules
@@ -140,7 +140,7 @@ def RevealThat(Subject, Text, SendMethod = None, Attachment = None, Attachhint =
         if EMAILsend(EmailTo     = smscnf.EMAILADDRESS,
                   Subject        = 'NOKIA N900[%s]: %s' % (Hostname, Subject),
                   Text           = 'Nokia phone "%s" at %s:\n%s\n' % (Hostname, GetTimeString(), Text),
-                  SuccessLogMsg  = 'sent email message (subject=%s) to <%s>' % (Subject, smscnf.EMAILADDRESS),
+                  SuccessLogMsg  = 'Sent email message (subject=%s) to <%s>.' % (Subject, smscnf.EMAILADDRESS),
                   Attachment = Attachment,
                   Attachhint = Attachhint):
             Revealed.append(smscnf.EMAILADDRESS)
@@ -424,9 +424,17 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
             AttachmentCID         = 'image%s' % random.randint(1, 100000)
             MailBodyHtml += '<br><img src="cid:%s" alt="%s" /><br>' % (AttachmentCID, AltText)
 
+    # For historical reasons, EMAILFROM contains the technical sender if EMAILSENDER is empty
+    if smscnf.EMAILSENDER:
+        TechnicalSender, LogicalSender = smscnf.EMAILSENDER, smscnf.EMAILFROM
+    else:
+        TechnicalSender, LogicalSender = smscnf.EMAILFROM, None
+
     Message['Subject'] = Subject
     Message['To']      = EmailTo
-    Message['From']    = 'NokiaN900.SMSCON.%s <SMSCON@%s>' % (Hostname, Hostname)
+    Message['From']    = LogicalSender or 'NokiaN900.SMSCON.%s <SMSCON@%s>' % (Hostname, Hostname)
+
+    LOGGER.debug('(EMAIL) LogicalSender=%s, TechnicalSender=%s, Recipient=%s, Subject=%s' % (LogicalSender, TechnicalSender, EmailTo, Subject))  
 
     MailBodyHtml = '<html><head></head><body>\n'\
                     '<p>' + MailBodyHtml + '</p>\n'\
@@ -457,13 +465,12 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
         Message.attach(AttachmentData)
 
     try:
-        LOGGER.info('(EMAIL) Trying to connect to "%s:%s" (%s).' % ( smscnf.MAILSERVER, smscnf.MAILPORT, GetTimeString() ) )
-
+        LOGGER.info('(EMAIL) Connecting mail server "%s:%s".' % (smscnf.MAILSERVER, smscnf.MAILPORT))
         # connect to mail server
         Server = smtplib.SMTP(smscnf.MAILSERVER, smscnf.MAILPORT) 
         #Server.set_debuglevel(True)
     except (socket.error, smtplib.SMTPConnectError, smtplib.SMTPException):
-        LOGGER.error('(EMAIL) Mailserver connection failure%s.' % RetryInfo)
+        LOGGER.error('(EMAIL) Failed to connect mail server%s.' % RetryInfo)
         return False
 
     # identify to mail server
@@ -477,25 +484,24 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
     # if smtp server requires user/password authentication
     if smscnf.USER != '' and smscnf.PASSWORD != '':
         try:
-            LOGGER.info('(EMAIL) Trying to login to "%s".' % smscnf.MAILSERVER)
+            LOGGER.debug('(EMAIL) Login at mail server "%s" as "%s", PW:%s...' % (smscnf.MAILSERVER, smscnf.USER, IF(smscnf.PASSWORD,'yes','no')))
             Server.login(smscnf.USER, smscnf.PASSWORD) 
         except smtplib.SMTPAuthenticationError:
-            LOGGER.error('(EMAIL) Wrong username/password%s.' % RetryInfo)
+            LOGGER.error('(EMAIL) Mail not sent. Wrong username/password%s.' % RetryInfo)
             Server.quit()
             return False
 
     try:
-        LOGGER.info('(EMAIL) Trying to send email to "%s".' % smscnf.MAILSERVER)
-        Server.sendmail(smscnf.EMAILFROM, EmailTo, Message.as_string()) 
+        LOGGER.debug('(EMAIL) Transferring email...')
+        Server.sendmail(TechnicalSender, EmailTo, Message.as_string()) 
     except smtplib.SMTPException, e:
-        LOGGER.error('(EMAIL) [%s].' % e)
+        LOGGER.error('(EMAIL) Transfer failed: %s' % e)
         Server.quit()
-        LOGGER.error('(EMAIL) Mailserver connection closed%s.' % RetryInfo)
+        LOGGER.error('(EMAIL) Mail not sent%s.' % RetryInfo)
         return False
 
-    LOGGER.info(SuccessLogMsg)
-    LOGGER.info('(EMAIL) Mailserver connection closed successful.')
     Server.quit()
+    LOGGER.info('(EMAIL) %s' % (SuccessLogMsg or 'Mail sent.'))
     return True
 
 #############################################
@@ -1076,7 +1082,7 @@ def PerformCamera(args = []):
                   Subject =  'NOKIA N900[%s]: %s' % (Hostname, smscnf.COM_CAMERA),
                   Text    =  ['Frontcam picture from Nokia N900 phone:\n',
                               'Taken on %s at %s\n' % (Hostname, GetTimeString())],
-                  SuccessLogMsg  = '(EMAIL) camera picture sent to "%s"' % smscnf.EMAILADDRESS,
+                  SuccessLogMsg  = 'Sent camera picture to "%s".' % smscnf.EMAILADDRESS,
                   Attachment =  ImageFilename,
                   Attachhint = 'image' )
 
@@ -1813,9 +1819,9 @@ def ValidateIMSI():
     if CurrentIMSI == None:
         # Use silent calls to lock/unlock and RevealThat situation once only:
         if smscnf.SIMUNLOCK == 'yes':
-            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock on no SIM.'
+            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock if no SIM.'
         elif smscnf.SIMUNLOCK == 'locknewsim':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock no SIM.'
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock if no SIM.'
         elif smscnf.SIMUNLOCK == 'lockalways':
             DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
 
@@ -1836,9 +1842,9 @@ def ValidateIMSI():
     else:
         # Use silent calls to lock/unlock and RevealThat situation once only:
         if smscnf.SIMUNLOCK == 'yes':
-            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock on new SIM.'
+            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock if new SIM.'
         elif smscnf.SIMUNLOCK == 'locknewsim':
-            DeviceLockStatus = __DoDeviceLock() + ' Because lock new SIM.'
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock if new SIM.'
         elif smscnf.SIMUNLOCK == 'lockalways':
             DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
 
@@ -1931,14 +1937,14 @@ def DoCommandLine(args):
                     EMAILsend(EmailTo = smscnf.EMAILADDRESS,
                               Subject = 'Test email / Nokia N900',
                               Text = 'Email sending from Nokia N900 phone is successful!',
-                              SuccessLogMsg = 'sent test email message to "%s"' % smscnf.EMAILADDRESS)
+                              SuccessLogMsg = 'Sent test email message to <%s>.' % smscnf.EMAILADDRESS)
                 elif Func == 'email2': # test mode2 for email + frontcam image
                     ImageFilename = TakeFrontCamPicture()
                     if ImageFilename:
                         EMAILsend(EmailTo = smscnf.EMAILADDRESS,
                               Subject =  'Test email / Nokia N900',
                               Text =  'Frontcam picture from Nokia N900 phone:<br>%s<br>' % GetTimeString(),
-                              SuccessLogMsg = 'camera picture sent to "%s"' % smscnf.EMAILADDRESS,
+                              SuccessLogMsg = 'Sent camera picture to <%s>.' % smscnf.EMAILADDRESS,
                               Attachment =  ImageFilename,
                               Attachhint = 'image' )
 
@@ -1973,7 +1979,7 @@ def DoCommandLine(args):
             EMAILsend(EmailTo = Recipient,
                   Subject        = 'NOKIA N900[%s]: %s' % (Hostname, Subject),
                   Text           = 'Nokia phone "%s" at %s:\n%s\n' % (Hostname, GetTimeString(), Text),
-                  SuccessLogMsg  = 'sent email message (subject=%s) to <%s>' % (Subject, Recipient),
+                  SuccessLogMsg  = 'Sent email message (subject=%s) to <%s>.' % (Subject, Recipient),
                   Attachment = AttachmentFileName,
                   Attachhint = AttachmentMimeType)
         else:
