@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 188 2012-06-04 21:55:49Z yablacky $
+# $Id: smsconlib.py 192 2012-06-05 23:01:07Z yablacky $
 ##############################################################
 
 # standard modules
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.10.1/src/opt/smscon/smsconlib.py 188 2012-06-04 21:55:49Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.10.2/src/opt/smscon/smsconlib.py 192 2012-06-05 23:01:07Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -787,7 +787,8 @@ class UserConfiguration(Configuration):
         'EMAILADDRESS':     (_EmailPattern,     'to@example.com',   _OPT_PLAIN, '# Recipient of EMAIL notifications (regular owner of this phone, please contact him!):'),
         'USER':             ('',                '',                 _OPT_CRYPT, '# SMTP username for EMAILFROM (encrypted):'),
         'PASSWORD':         ('',                '',                 _OPT_CRYPT, '# SMTP password for EMAILFROM (encrypted):'),
-        'EMAILFROM':        (_EmailPattern,     'from@example.com', _OPT_CRYPT, '# Sender address of EMAIL notification (encrypted):'),
+        'EMAILFROM':        (_EmailPattern,     'from@example.com', _OPT_CRYPT, '# Logical sender address of EMAIL notification (encrypted):'),
+        'EMAILSENDER':      (_EmailPattern,     '',                 _OPT_CRYPT, '# Technical sender address of EMAIL notification (encrypted):'),
         'MAILSERVER':       (_HostnamePattern,  'smtp.example.com', _OPT_CRYPT, '# SMTP server hostname or IP (encrypted):'),
         'MAILPORT':         (_IntPattern,       '25',               _OPT_PLAIN, '# SMTP server port number:'),
 
